@@ -11,7 +11,7 @@ check_bread <- function(obj, cluster, y, check_coef = TRUE, tol = .Machine$doubl
   M <- chol2inv(chol(XWX))
   attr(M, "dimnames") <- attr(B, "dimnames")
   
-  eq_bread <- diff(range(B / M)) < tol
+  eq_bread <- diff(range((B / M)[XWX != 0])) < tol
   
   if (check_coef) {
     coef <- coef_CS(obj)
@@ -43,21 +43,21 @@ check_CR <- function(obj, vcov, ..., tol = .Machine$double.eps^0.5) {
          
   # calculate target
   Theta_list <- attr(vcov, "target")
-  Xp <- projection_matrix(obj)
+  X <- model_matrix(obj)
   alias <- is.na(coef_CS(obj))
-  if (any(alias)) Xp <- Xp[, !alias, drop = FALSE]
-  p <- NCOL(Xp)
+  if (any(alias)) X <- X[, !alias, drop = FALSE]
+  p <- NCOL(X)
   N <- length(cluster)
   J <- nlevels(cluster)
   
-  Xp_list <- matrix_list(Xp, cluster, "row")
+  X_list <- matrix_list(X, cluster, "row")
   W_list <- weightMatrix(obj, cluster)
-  XpW_list <- Map(function(x, w) as.matrix(t(x) %*% w), x = Xp_list, w = W_list)
+  XW_list <- Map(function(x, w) as.matrix(t(x) %*% w), x = X_list, w = W_list)
   M <- attr(vcov, "bread") / attr(vcov, "v_scale")
   attr(M, "dimnames") <- NULL
 
   MXWTWXM <- Map(function(xw, theta) M %*% as.matrix(xw %*% theta %*% t(xw)) %*% M, 
-                    xw = XpW_list, theta = Theta_list)
+                    xw = XW_list, theta = Theta_list)
   eq <- all.equal(E_CRj, MXWTWXM, tolerance = tol)
   if (all(eq==TRUE)) TRUE else list(E_CRj = E_CRj, target = MXWTWXM)
 }
