@@ -21,8 +21,8 @@ test_that("vcov arguments work", {
   dat <- balanced_dat(m = 15, n = 8)
   lm_fit <- lm(y ~ X_btw + X_wth, data = dat)
   VCR <- lapply(CRs, function(t) vcovCR(lm_fit, cluster = dat$cluster, type = t))
-  test_A <- lapply(VCR, function(v) coef_test(lm_fit, vcov = v, test = "All"))
-  test_B <- lapply(CRs, function(t) coef_test(lm_fit, vcov = t, cluster = dat$cluster, test = "All"))
+  test_A <- lapply(VCR, function(v) coef_test(lm_fit, vcov = v, test = "All", p_values = FALSE))
+  test_B <- lapply(CRs, function(t) coef_test(lm_fit, vcov = t, cluster = dat$cluster, test = "All", p_values = FALSE))
   expect_identical(test_A, test_B)
 })
 
@@ -55,10 +55,10 @@ test_that("coefs argument works", {
   dat <- balanced_dat(m = 15, n = 8)
   lm_fit <- lm(y ~ X_btw + X_wth, data = dat)
   which_grid <- expand.grid(rep(list(c(FALSE,TRUE)), length(coef(lm_fit))))
-  tests_all <- coef_test(lm_fit, vcov = "CR0", cluster = dat$cluster, test = "All", coefs = "All")
+  tests_all <- coef_test(lm_fit, vcov = "CR0", cluster = dat$cluster, test = "All", coefs = "All", p_values = FALSE)
   
   tests_A <- apply(which_grid[-1,], 1, function(x) tests_all[x,])
-  tests_B <- apply(which_grid[-1,], 1, function(x) coef_test(lm_fit, vcov = "CR0", cluster = dat$cluster, test = "All", coefs = x))
+  tests_B <- apply(which_grid[-1,], 1, function(x) coef_test(lm_fit, vcov = "CR0", cluster = dat$cluster, test = "All", coefs = x, p_values = FALSE))
   expect_identical(tests_A, tests_B)
 })
 
